package App::ph;
use strict;
use warnings;
use 5.008008;
our $VERSION = '0.01';



1;
__END__

=encoding utf8

=head1 NAME

App::ph - yet another github client command

=head1 SYNOPSIS

    $ ph info mattn gal-vim
    $ ph clone mattn gal-vim
    $ ph import

=head1 DESCRIPTION

App::ph is yet another github client command, supports github API v3.

=head1 AUTHOR

Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF@ GMAIL COME<gt>

=head1 SEE ALSO

L<App::gh>, L<Pithub>

=head1 LICENSE

Copyright (C) Tokuhiro Matsuno

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
